summaryrefslogtreecommitdiff
path: root/com32/lib/syslinux/dump_mmap.c
diff options
context:
space:
mode:
authorH. Peter Anvin <hpa@zytor.com>2011-06-27 19:06:43 -0700
committerH. Peter Anvin <hpa@zytor.com>2012-05-18 16:04:00 -0700
commit06531db8ec5d58477d7083d3d8130e909206233f (patch)
tree864b5572c8cab87184fe9a93e6f17b35ff3b5c35 /com32/lib/syslinux/dump_mmap.c
parentbe697f88819ef20d72d1e7ea7d3d975d1fed5fb0 (diff)
downloadsyslinux-06531db8ec5d58477d7083d3d8130e909206233f.tar.gz
com32: make syslinux_dump_*() pure debugging functions
Make the syslinux_dump_*() functions pure debugging functions; that is the way that they are used anyway, and this way they log to the same place as dprintf. Signed-off-by: H. Peter Anvin <hpa@zytor.com>
Diffstat (limited to 'com32/lib/syslinux/dump_mmap.c')
-rw-r--r--com32/lib/syslinux/dump_mmap.c12
1 files changed, 7 insertions, 5 deletions
diff --git a/com32/lib/syslinux/dump_mmap.c b/com32/lib/syslinux/dump_mmap.c
index 3f1e340b..85638cd9 100644
--- a/com32/lib/syslinux/dump_mmap.c
+++ b/com32/lib/syslinux/dump_mmap.c
@@ -28,20 +28,22 @@
/*
* dump_mmap.c
*
* Writes a syslinux_memmap out to a specified file. This is
* intended for debugging.
*/
#include <stdio.h>
+#include <dprintf.h>
#include <syslinux/movebits.h>
-void syslinux_dump_memmap(FILE * file, struct syslinux_memmap *memmap)
+#ifdef DEBUG
+void syslinux_dump_memmap(struct syslinux_memmap *memmap)
{
- fprintf(file, "%10s %10s %10s\n"
+ dprintf("%10s %10s %10s\n"
"--------------------------------\n", "Start", "Length", "Type");
while (memmap->next) {
- fprintf(file, "0x%08x 0x%08x %10d\n", memmap->start,
+ dprintf("0x%08x 0x%08x %10d\n", memmap->start,
memmap->next->start - memmap->start, memmap->type);
memmap = memmap->next;
}
}
+#endif
@@ -28,20 +28,22 @@
* dump_mmap.c
*
- * Writes a syslinux_memmap out to a specified file. This is
- * intended for debugging.
+ * Writes a syslinux_memmap out to a dprintf.
*/
#include <stdio.h>